@@ -18,7 +18,7 @@ use Encode;
 use RDF::RDFa::Generator 0.102;
 use HTML::HTML5::Writer qw(DOCTYPE_XHTML_RDFA);
 use Data::Dumper;
-use Digest::MD5 ('md5_hex');
+use Digest::MD5 ('md5_base64');
 
 
 with 'MooseX::Log::Log4perl::Easy';
@@ -44,11 +44,11 @@ RDF::LinkedData - A simple Linked Data server implementation
 
 =head1 VERSION
 
-Version 0.64
+Version 0.66
 
 =cut
 
- our $VERSION = '0.64';
+ our $VERSION = '0.66';
 
 
 =head1 SYNOPSIS
@@ -322,9 +322,11 @@ sub response {
 			my $content = $self->_content($node, $type, $endpoint_path);
 			$response->headers->header('Vary' => join(", ", qw(Accept)));
 			if (defined($self->current_etag)) {
-				$self->current_etag =~ m|(^W/)|; # If the ETag is declared as weak, preserve that
-				my $weak = defined($1) ? $1 : '';
-				$response->headers->header('ETag' => $weak . md5_hex($self->current_etag . $content->{content_type}));
+			  my $weak = '';
+			  if ($self->current_etag =~ m|^W/|) { # If the ETag is declared as weak, preserve that
+				 $weak = 'W/';
+			  }
+			  $response->headers->header('ETag' => '"' . $weak . md5_base64($self->current_etag . $content->{content_type}) . '"');
 			}
 			$response->headers->content_type($content->{content_type});
 			$response->body(encode_utf8($content->{body}));
@@ -626,9 +628,11 @@ sub _void_content {
 		$etag = $self->_last_extvoid_mtime if ($self->void_config->{add_void});
 		$etag .= $self->last_etag if (defined($self->last_etag));
 		if ($etag) {
-			$etag =~ m|(^W/)|; # If the ETag is declared as weak, preserve that
-			my $weak = defined($1) ? $1 : '';
-			$response->headers->header('ETag' => $weak . md5_hex($etag . $ct));
+		  my $weak = '';
+		  if($etag =~ m|^W/|) { # If the ETag is declared as weak, preserve that
+			 $weak = 'W/';
+		  }
+		  $response->headers->header('ETag' => '"' . $weak . md5_base64($etag . $ct) . '"');
 		}
 		$response->headers->content_type($ct);
 		$response->body(encode_utf8($body));
@@ -696,7 +700,7 @@ Copyright 2010 Gregory Todd Williams
 
 Copyright 2010 ABC Startsiden AS
 
-Copyright 2010, 2011, 2012, 2013 Kjetil Kjernsmo
+Copyright 2010, 2011, 2012, 2013, 2014 Kjetil Kjernsmo
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
